@@ -1,4 +1,4 @@
-NanoStringNorm <- function(x, anno = NA, header = NA, Probe.Correction.Factor = 'none', CodeCount = 'none', Background = 'none', SampleContent = 'none', OtherNorm = 'none', round.values = FALSE, log = FALSE, return.matrix.of.endogenous.probes = FALSE, traits = NA, predict.conc = FALSE, verbose = TRUE, genes.to.fit = NA, genes.to.predict = NA, ...) {
+NanoStringNorm <- function(x, anno = NA, header = NA, Probe.Correction.Factor = 'adjust', CodeCount = 'none', Background = 'none', SampleContent = 'none', OtherNorm = 'none', round.values = FALSE, log = FALSE, return.matrix.of.endogenous.probes = FALSE, traits = NA, predict.conc = FALSE, verbose = TRUE, genes.to.fit = NA, genes.to.predict = NA, ...) {
 
 	# get correct list item from xls or NSN output
 	if (class(x) == 'NanoString') {
@@ -22,7 +22,7 @@ NanoStringNorm <- function(x, anno = NA, header = NA, Probe.Correction.Factor =
 			stop ('NanoStringNorm: One of the annotation columuns (Code.Class,Name, Accession) is a factor.  Please convert to a character value to avoid issues');
 			}
 
-		# remove probe level warning message line from data
+		# remove probe level warning message line from data (old format)
 		if ( grepl('+++ Functional tests', x[nrow(x),'Name'], fixed = TRUE) ){
 			x <- x[-nrow(x),];
 			}
@@ -76,13 +76,18 @@ NanoStringNorm <- function(x, anno = NA, header = NA, Probe.Correction.Factor =
 		cat('##############################\n\n');
 		cat(paste('There are', ncol(x),'samples and', sum(grepl('Endogenous', anno$Code.Class)), 'Endogenous genes \n\n')); 
 		}
+
+	# Check data for NA's
+	if (any(is.na(x))) {
+		stop('NanoStringNorm: There are NA values in your data');
+		}
 	
 	# Check data is a numeric matrix
 	if (any(!is.numeric(x))) {
 		stop('NanoStringNorm: There are character values in your data.  Check that you labelled the annotation columns correctly');
 		}
 
-	# Check data in positive
+	# Check data is positive
 	if (any(x < 0)) {
 		stop('NanoStringNorm: There are negative values in your data');
 		}
@@ -118,7 +123,7 @@ NanoStringNorm <- function(x, anno = NA, header = NA, Probe.Correction.Factor =
 	if ( !Background %in% c('none', 'mean', 'mean.2sd', 'max') ) {
 		stop('NanoStringNorm: Unrecognized Background Normalization method');
 		}
-	if ( !SampleContent %in% c('none', 'housekeeping.sum', 'housekeeping.geo.mean', 'total.sum', 'top.mean', 'top.geo.mean') ) {
+	if ( !SampleContent %in% c('none', 'housekeeping.sum', 'housekeeping.geo.mean', 'total.sum', 'top.mean', 'top.geo.mean', 'low.cv.geo.mean') ) {
 		stop('NanoStringNorm: Unrecognized SampleContent Normalization method');
 		}
 	if ( !OtherNorm %in% c('none', 'quantile', 'zscore', 'rank.normal', 'vsn') ) {
@@ -152,7 +157,7 @@ NanoStringNorm <- function(x, anno = NA, header = NA, Probe.Correction.Factor =
 		}
 
 	# do Sample Content Normalization
-	if ( SampleContent %in% c('housekeeping.sum', 'housekeeping.geo.mean', 'total.sum', 'top.mean', 'top.geo.mean') ) {
+	if ( SampleContent %in% c('housekeeping.sum', 'housekeeping.geo.mean', 'total.sum', 'top.mean', 'top.geo.mean', 'low.cv.geo.mean') ) {
 		output.sample.content.normalization <- NanoStringNorm:::sample.content.normalization(x, anno, SampleContent, verbose);
 		x <- output.sample.content.normalization$x;
 		sampleContent.norm.factor <- output.sample.content.normalization$sampleContent.norm.factor;
